promptio

package
v0.5.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package promptio provides context-aware interactive terminal input.

Stdin reads are not cancellable, so helpers run the read in a goroutine and return early on ctx cancellation; the goroutine leaks until process exit.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ReadLine

func ReadLine(ctx context.Context, msg string) (string, error)

func ReadPassword

func ReadPassword(ctx context.Context, msg string) (string, error)

Types

This section is empty.

Jump to